@@ -57,21 +57,19 @@ function recreate_endpoint {
 
     if [[ "$KEYSTONE_CATALOG_BACKEND" = 'sql' ]]; then
 
-        # Remove nova's ec2 service/endpoint
-        local endpoint_id=$(openstack endpoint list \
-            --column "ID" \
-            --column "Region" \
-            --column "Service Name" \
-            | grep " $REGION_NAME " \
-            | grep " $endpoint " | get_field 1)
-        if [[ -n "$endpoint_id" ]]; then
-            openstack endpoint delete $endpoint_id
+        # Remove nova's service/endpoint
+        local endpoint_ids=$(openstack --os-identity-api-version 3 endpoint list \
+            --service "$endpoint" --region "$REGION_NAME" -c ID -f value)
+        if [[ -n "$endpoint_ids" ]]; then
+            for endpoint_id in $endpoint_ids ; do
+                openstack --os-identity-api-version 3 endpoint delete $endpoint_id
+            done
         fi
-        local service_id=$(openstack service list \
+        local service_id=$(openstack --os-identity-api-version 3 service list \
             -c "ID" -c "Name" \
             | grep " $endpoint " | get_field 1)
         if [[ -n "$service_id" ]]; then
-            openstack service delete $service_id
+            openstack --os-identity-api-version 3 service delete $service_id
         fi
 
         local service_id=$(openstack service create \
@@ -79,12 +77,12 @@ function recreate_endpoint {
             --name "$endpoint" \
             --description="$description" \
             -f value -c id)
-        openstack endpoint create \
-            $service_id \
-            --region "$REGION_NAME" \
-            --publicurl "$protocol://$SERVICE_HOST:$port/" \
-            --adminurl "$protocol://$SERVICE_HOST:$port/" \
-            --internalurl "$protocol://$SERVICE_HOST:$port/"
+        openstack --os-identity-api-version 3 endpoint create --region "$REGION_NAME" \
+            $service_id public "$protocol://$SERVICE_HOST:$port/"
+        openstack --os-identity-api-version 3 endpoint create --region "$REGION_NAME" \
+            $service_id admin "$protocol://$SERVICE_HOST:$port/"
+        openstack --os-identity-api-version 3 endpoint create --region "$REGION_NAME" \
+            $service_id internal "$protocol://$SERVICE_HOST:$port/"
     fi
 }
 
@@ -167,41 +165,31 @@ function configure_ec2api {
     mkdir_chown_stack "$EC2API_CONF_DIR"
 
     # Generate ec2api configuration file and configure common parameters.
-    oslo-config-generator --namespace keystonemiddleware.auth_token \
-                          --namespace ec2api \
-                          --namespace oslo.db \
-                          --namespace oslo.messaging \
-                          > $EC2API_CONF_FILE
+    sudo rm -f $EC2API_CONF_FILE
+    touch $EC2API_CONF_FILE
     cp $EC2API_DIR/etc/ec2api/api-paste.ini $EC2API_CONF_DIR
 
     cleanup_ec2api
 
     iniset $EC2API_CONF_FILE DEFAULT debug $EC2API_DEBUG
     iniset $EC2API_CONF_FILE DEFAULT use_syslog $SYSLOG
-    iniset $EC2API_CONF_FILE DEFAULT state_path EC2API_STATE_PATH
+    iniset $EC2API_CONF_FILE DEFAULT state_path $EC2API_STATE_PATH
 
 
     # ec2api Api Configuration
     #-------------------------
 
-    # Setup keystone_authtoken section
-    iniset $EC2API_CONF_FILE keystone_authtoken auth_uri "http://${KEYSTONE_AUTH_HOST}:5000/v2.0"
-    iniset $EC2API_CONF_FILE keystone_authtoken auth_host $KEYSTONE_AUTH_HOST
-    iniset $EC2API_CONF_FILE keystone_authtoken auth_port $KEYSTONE_AUTH_PORT
-    iniset $EC2API_CONF_FILE keystone_authtoken auth_protocol $KEYSTONE_AUTH_PROTOCOL
-    iniset $EC2API_CONF_FILE keystone_authtoken cafile $KEYSTONE_SSL_CA
-    iniset $EC2API_CONF_FILE keystone_authtoken admin_tenant_name $SERVICE_TENANT_NAME
-    iniset $EC2API_CONF_FILE keystone_authtoken admin_user $EC2API_ADMIN_USER
-    iniset $EC2API_CONF_FILE keystone_authtoken admin_password $SERVICE_PASSWORD
-    iniset $EC2API_CONF_FILE keystone_authtoken signing_dir $EC2API_KEYSTONE_SIGNING_DIR
-
     iniset $EC2API_CONF_FILE DEFAULT admin_tenant_name $SERVICE_TENANT_NAME
     iniset $EC2API_CONF_FILE DEFAULT admin_user $EC2API_ADMIN_USER
     iniset $EC2API_CONF_FILE DEFAULT admin_password $SERVICE_PASSWORD
 
-    iniset $EC2API_CONF_FILE DEFAULT keystone_url "$KEYSTONE_SERVICE_PROTOCOL://${KEYSTONE_AUTH_HOST}:35357/v2.0"
+    iniset $EC2API_CONF_FILE DEFAULT ec2api_workers "$API_WORKERS"
+    iniset $EC2API_CONF_FILE DEFAULT keystone_url "$KEYSTONE_SERVICE_PROTOCOL://$KEYSTONE_SERVICE_HOST:$KEYSTONE_SERVICE_PORT/v2.0"
     iniset $EC2API_CONF_FILE DEFAULT region_list "$REGION_NAME"
 
+    iniset $EC2API_CONF_FILE DEFAULT ec2api_listen_port "$EC2API_SERVICE_PORT"
+    iniset $EC2API_CONF_FILE DEFAULT ec2_port "$EC2API_SERVICE_PORT"
+
     if is_service_enabled swift3; then
         iniset $EC2API_CONF_FILE DEFAULT s3_port "$S3_SERVICE_PORT"
     else
@@ -226,6 +214,7 @@ function configure_ec2api {
     configure_ec2api_networking
 
     # metadata configuring
+    iniset $EC2API_CONF_FILE DEFAULT metadata_workers "$API_WORKERS"
     if [[ ,${ENABLED_SERVICES} =~ ,"q-" ]]; then
         # with neutron
         iniset $Q_META_CONF_FILE DEFAULT nova_metadata_port 8789
@@ -252,13 +241,6 @@ function install_ec2api() {
     # both functions (setup_develop and setup_package) are defined at:
     # http://git.openstack.org/cgit/openstack-dev/devstack/tree/functions-common
     setup_package $EC2API_DIR -e
-
-    # NOTE(andrey-mp): temporary install euca2ools
-    # waiting for review https://review.openstack.org/#/c/169027/
-    # that review adds euca2ools installation into devstack
-    # scripts with tempest. euca2ools are needed for bundling image
-    # in tempest preparation scripts.
-    is_package_installed euca2ools || install_package euca2ools
 }
 
 
@@ -284,6 +266,15 @@ function cleanup_ec2api() {
     sudo rm -rf $EC2API_KEYSTONE_SIGNING_DIR
 }
 
+function configure_functional_tests() {
+    (source $EC2API_DIR/devstack/create_config "functional_tests.conf")
+    if [[ "$?" -ne "0" ]]; then
+        warn $LINENO "EC2 API tests config could not be created."
+    elif is_service_enabled tempest; then
+        cat "$EC2API_DIR/functional_tests.conf" >> $TEMPEST_CONFIG
+    fi
+}
+
 # main dispatcher
 if [[ "$1" == "stack" && "$2" == "install" ]]; then
     echo_summary "Installing ec2-api"
@@ -296,6 +287,7 @@ elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
     echo_summary "Initializing ec2-api"
     init_ec2api
     start_ec2api
+    configure_functional_tests
 fi
 
 if [[ "$1" == "unstack" ]]; then
